/*******************************************************************************

    Program:        custlist.p
    
    Description:    Illustrates how to interact Progress reporting requirements
                    with PDFinclude

*******************************************************************************/

{ ./pdf_inc.i }

DEFINE VARIABLE Vlines      AS INTEGER NO-UNDO.
DEFINE VARIABLE Vpage       AS INTEGER NO-UNDO.
DEFINE VARIABLE Vold_Y      AS INTEGER NO-UNDO.

/* Create stream for new PDF file */
RUN pdf_new        ("Spdf","c:\sports2000\PDFinc\custlist.pdf").

/* Load Bar Code Font */
RUN pdf_load_font  ("Spdf","Code39","c:\windows\fonts\code39.ttf","c:\sports2000\code39.afm").

/* Load PRO-SYS Logo File */
RUN pdf_load_image ("Spdf","ProSysLogo","c:\sports2000\pdfinc\prosyslogo.jpg").

/* Set Document Information */ 
RUN pdf_set_info("Spdf","Author","Gordon Campbell").
RUN pdf_set_info("Spdf","Subject","Accounts Receivable").
RUN pdf_set_info("Spdf","Title","Customer List").
RUN pdf_set_info("Spdf","Keywords","Customer List Accounts Receivable").
RUN pdf_set_info("Spdf","Creator","PDFinclude").
RUN pdf_set_info("Spdf","Producer","custlist.p").

/* Instantiate a New Page */
RUN new_page.

/* Loop through appropriate record set */
FOR EACH customer WHERE NAME BEGINS "A" NO-LOCK 
    BREAK BY State
          BY CustNum:

  /* Output the appropriate Record information */
  RUN pdf_set_font ("Spdf","Courier-Oblique",10.0).
  RUN pdf_text_at  ("Spdf", customer.state,1).
  RUN pdf_set_font ("Spdf","Courier",10.0).
  RUN pdf_text_at  ("Spdf", STRING(customer.CustNum,">>>9"),6).
  RUN pdf_text_at  ("Spdf", customer.NAME,12).
  RUN pdf_text_at  ("Spdf", customer.phone,44).
  RUN pdf_text_to  ("Spdf", STRING(customer.balance),80).

  /* Display a BarCode for each Customer Number */
  RUN pdf_set_font ("Spdf","Code39",10.0).

  Vold_Y = pdf_TextY("Spdf").  /* Store Original Text Path */
  RUN pdf_text_xy ("Spdf", STRING(customer.CustNum,"999999"),500, pdf_textY("Spdf")).
  RUN pdf_set_TextY("Spdf",Vold_y). /* Reset Original Text Path */
  RUN pdf_set_font ("Spdf","Courier",10.0).

  /* Skip to Next Text Line */
  RUN pdf_skip    ("Spdf").  
  
  /* Process Line Counter */
  Vlines = Vlines + 1.
  IF Vlines = 60 THEN
    RUN new_page.

  IF LAST-OF(State) THEN DO:
    IF Vlines + 2 > 60 THEN
      RUN new_page.

    /* Put a red line between each of the states */
    RUN pdf_skip ("Spdf").
    RUN pdf_stroke_color ("Spdf",1.0,.0,.0).
    RUN pdf_set_dash ("Spdf",2,2).
    RUN pdf_line  ("Spdf", pdf_LeftMargin("Spdf") , pdf_TextY("Spdf") + 5, pdf_PageWidth("Spdf") - 20 , pdf_TextY("Spdf") + 5, 1).
    RUN pdf_stroke_color ("Spdf",.0,.0,.0).
    RUN pdf_skip    ("Spdf").

    Vlines = Vlines + 2.
  END. /* Last-of State */
END.

RUN end_of_report.

RUN pdf_close("Spdf").

/* -------------------- INTERNAL PROCEDURES -------------------------- */

PROCEDURE new_page:
  
  /* Display Footer UnderLine */
  IF Vpage > 0 THEN 
    RUN page_footer.
  
  RUN pdf_new_page("Spdf").
  
  Vpage = Vpage + 1.
  
  /* Place Logo but only on first page of Report */
  IF Vpage = 1 THEN DO:
    RUN pdf_place_image ("Spdf","ProSysLogo",pdf_LeftMargin("Spdf"), pdf_TopMargin("Spdf") - 20 ,179,20).
  END.

  /* Set Header Font Size and Colour */
  RUN pdf_set_font ("Spdf","Courier-Bold",10.0).  
  RUN pdf_text_color ("Spdf",1.0,.0,.0).

  /* Put a Rectangle around the Header */
  RUN pdf_stroke_color ("Spdf", .0,.0,.0).
  RUN pdf_stroke_fill ("Spdf", .9,.9,.9).
  RUN pdf_rect ("Spdf", pdf_LeftMargin("Spdf"), pdf_TextY("Spdf") - 3, pdf_PageWidth("Spdf") - 30  , pdf_TextX("Spdf") + 12).

  /* Output Report Header */
  RUN pdf_text_at  ("Spdf","St",1).
  RUN pdf_text_at  ("Spdf","Nbr",6).
  RUN pdf_text_at  ("Spdf","Customer Name",12). 
  RUN pdf_text_at  ("Spdf","Phone Number",44).
  RUN pdf_text_to  ("Spdf","Balance",80).

  /* Display Header UnderLine */
  RUN pdf_skip ("Spdf").
  RUN pdf_set_dash ("Spdf",1,0).
  RUN pdf_line  ("Spdf", pdf_LeftMargin("Spdf"), pdf_TextY("Spdf") + 5, pdf_PageWidth("Spdf") - 20 , pdf_TextY("Spdf") + 5, 2).
  RUN pdf_skip ("Spdf").
  
  /* Set Detail Font Colour */
  RUN pdf_text_color ("Spdf",.0,.0,.0).
  
  Vlines = 3.
END. /* new_page */

PROCEDURE page_footer:
  RUN pdf_skip ("Spdf").
  RUN pdf_set_dash ("Spdf",1,0).
  RUN pdf_line  ("Spdf", 0, pdf_TextY("Spdf") - 5, pdf_PageWidth("Spdf") - 20 , pdf_TextY("Spdf") - 5, 2).
  RUN pdf_skip ("Spdf").
  RUN pdf_skip ("Spdf").
  RUN pdf_text_to  ("Spdf","Page: " + STRING(Vpage), 97).
END. /* page_footer */

PROCEDURE end_of_report:
  RUN page_footer. 
  
  /* Display Footer UnderLine and End of Report Tag (Centered) */
  RUN pdf_skip ("Spdf").
  RUN pdf_stroke_fill ("Spdf",1.0,1.0,1.0).
  RUN pdf_text_boxed_xy ("Spdf", "End of Report", 250, pdf_TextY("Spdf") - 20, pdf_Text_Width("Spdf","End of Report"), 16, "Left",1).
END. /* end_of_report */

/* end of custlist.p */
